@@ -877,12 +877,12 @@ void HCCharacter::State(HCCharacterState newState)
 
 u32 HCCharacter::Load(JFile &file)
 {
-	if (0 == file.Read(&subtype, sizeof(subtype)) ||
-			0 == file.Read(&pos.x, sizeof(pos.x)) ||
-			0 == file.Read(&pos.y, sizeof(pos.y)) ||
-			0 == file.Read(&vMax.x, sizeof(vMax.x)) ||
-			0 == file.Read(&vMax.y, sizeof(vMax.y)) ||
-			0 == file.Read(&maxJumpRows, sizeof(maxJumpRows)))
+	if (0 == file.ReadLE32(&subtype) ||
+			0 == file.ReadLE32(&pos.x) ||
+			0 == file.ReadLE32(&pos.y) ||
+			0 == file.ReadLE32(&vMax.x) ||
+			0 == file.ReadLE32(&vMax.y) ||
+			0 == file.ReadLE32(&maxJumpRows))
 	{
 		fprintf(stderr, "Error reading character's common parameters.\n");
 		return 1;
@@ -895,12 +895,12 @@ u32 HCCharacter::Load(JFile &file)
 
 u32 HCCharacter::Save(JFile &file)
 {
-	if (0 == file.Write(&subtype, sizeof(subtype)) ||
-			0 == file.Write(&pos.x, sizeof(pos.x)) ||
-			0 == file.Write(&pos.y, sizeof(pos.y)) ||
-			0 == file.Write(&vMax.x, sizeof(vMax.x)) ||
-			0 == file.Write(&vMax.y, sizeof(vMax.y)) ||
-			0 == file.Write(&maxJumpRows, sizeof(maxJumpRows)))
+	if (0 == file.WriteLE32(&subtype) ||
+			0 == file.WriteLE32(&pos.x) ||
+			0 == file.WriteLE32(&pos.y) ||
+			0 == file.WriteLE32(&vMax.x) ||
+			0 == file.WriteLE32(&vMax.y) ||
+			0 == file.WriteLE32(&maxJumpRows))
 	{
 		fprintf(stderr, "Error writing character's common parameters.\n");
 		return 1;
