@@ -341,7 +341,7 @@ u32 HCLevel::Load(JFile &file)
 	Destroy();
 
 	// Maximum time to complete the level, 0 means no timed
-	if (0 == file.Read(&maxTime, sizeof(maxTime)))
+	if (0 == file.ReadLE32(&maxTime))
 	{
 		fprintf(stderr, "Error reading the level completion time.\n");
 		perror("");
@@ -391,7 +391,7 @@ u32 HCLevel::Load(JFile &file)
 	HCEnemy::MaxYVeloccity(character.MaxVeloccity().y);
 		
 	// Loads the enemies
-	if (0 == file.Read(&numEnemies, sizeof(numEnemies)))
+	if (0 == file.ReadLE32(&numEnemies))
 	{
 		fprintf(stderr, "Error reading the number of enemies.\n");
 
@@ -445,7 +445,7 @@ u32 HCLevel::Load(JFile &file)
 	}
 	
 	// Loads the objects
-	if (0 == file.Read(&numObjects, sizeof(numObjects)))
+	if (0 == file.ReadLE32(&numObjects))
 	{
 		fprintf(stderr, "Error reading the number of objects.\n");
 
@@ -474,7 +474,7 @@ u32 HCLevel::Load(JFile &file)
 	}
 
 	// Loads the ropes
-	if (0 == file.Read(&numRopes, sizeof(numRopes)))
+	if (0 == file.ReadLE32(&numRopes))
 	{
 		fprintf(stderr, "Error reading the number of ropes.\n");
 
@@ -587,7 +587,7 @@ u32 HCLevel::Save(JFile &file)
 	s32 x, y;
 
 	// Time to complete the level
-	if (0 == file.Write(&maxTime, sizeof(maxTime)))
+	if (0 == file.WriteLE32(&maxTime))
 	{
 		fprintf(stderr, "Error writing the completion time.\n");
 
@@ -626,7 +626,7 @@ u32 HCLevel::Save(JFile &file)
 	character.Pos(x, y);
 	
 	// Stores the objects, enemies, ropes relative to the map top-left corner
-	if (0 == file.Write(&numEnemies, sizeof(numEnemies)))
+	if (0 == file.WriteLE32(&numEnemies))
 	{
 		fprintf(stderr, "Error writing the number of enemies.\n");
 
@@ -648,7 +648,7 @@ u32 HCLevel::Save(JFile &file)
 		enemies[i]->Pos(x, y);
 	}
 
-	if (0 == file.Write(&numObjects, sizeof(numObjects)))
+	if (0 == file.WriteLE32(&numObjects))
 	{
 		fprintf(stderr, "Error writing the number of objects.\n");
 
@@ -670,7 +670,7 @@ u32 HCLevel::Save(JFile &file)
 		objects[i]->Pos(x, y);
 	}
 
-	if (0 == file.Write(&numRopes, sizeof(numRopes)))
+	if (0 == file.WriteLE32(&numRopes))
 	{
 		fprintf(stderr, "Error writing the number of ropes.\n");
 
