@@ -753,6 +753,8 @@ HCed::HCed() : JApp("HCed v1.1", HCED_REFAPPWIDTH, HCED_REFAPPHEIGHT, false)
 	menuBarSubtype = 0;
 	menuLadderSubtype = 0;
 	menuRopeSubtype = 0;
+	appBackColor = 0;
+
 	for (s32 i = 0; i < HCENEMYTYPE_COUNT; ++i)
 	{
 		menuEnemySubtype[i] = 0;
@@ -1102,6 +1104,8 @@ bool HCed::Init(int argc, char **argv)
 		return false;
 	}
 
+	appBackColor = SDL_MapRGB(screen->format, 0x00, 0x00, 0x07);
+
 	OnFloor(this);
 
 	return true;
@@ -1910,7 +1914,7 @@ bool HCed::Draw()
 {
 	bool ret;
 
-	SDL_FillRect(screen, 0, 0x00000007);
+	SDL_FillRect(screen, 0, appBackColor);
 	level.Draw();
 	menuMain->Draw();
 	
@@ -2790,7 +2794,7 @@ void HCed::OnOpenStory(void *data)
 
 void HCed::OnSelectStory(void *data)
 {
-	if ((s32)data < 0)
+	if ((long)data < 0)
 	{
 		theApp->inputNewStory = HCED_INPUT_STORY;
 
@@ -2803,7 +2807,7 @@ void HCed::OnSelectStory(void *data)
 	else
 	{
 		theApp->OnFloor(0);
-		theApp->filename = JString(theApp->storyDir) + JString(HCUtil::Stories()[(s32)data]) + "/level001.hlv";
+		theApp->filename = JString(theApp->storyDir) + JString(HCUtil::Stories()[(long)data]) + "/level001.hlv";
 		
 		if (0 != theApp->NewLevel())
 		{
@@ -2811,7 +2815,7 @@ void HCed::OnSelectStory(void *data)
 			return;
 		}
 		
-		theApp->storyName = HCUtil::Stories()[(s32)data];
+		theApp->storyName = HCUtil::Stories()[(long)data];
 		theApp->levelNumber = 1;
 	}
 }
@@ -2829,7 +2833,7 @@ void HCed::OnSelectTheme(void *data)
 			JString oldTheme = theApp->themeName;
 			s32 oldLevel = theApp->levelNumber;
 			theApp->filename = JString(theApp->storyDir) + JString(theApp->strNewStoryName) + JString("/level001.hlv");
-			theApp->themeName = HCUtil::Themes()[(s32)data];
+			theApp->themeName = HCUtil::Themes()[(long)data];
 			theApp->levelNumber = 1;
 						
 			if (0 != theApp->NewLevel())
@@ -2866,60 +2870,60 @@ void HCed::OnAppExit(void *data)
 
 void HCed::OnMainSubtype(void *data)
 {
-	theApp->level.character.subtype = (s32)data;
-	theApp->level.character.Init(theApp->level.theme.MainChar((s32)data), &theApp->level.map);
+	theApp->level.character.subtype = (long)data;
+	theApp->level.character.Init(theApp->level.theme.MainChar((long)data), &theApp->level.map);
 }
 
 void HCed::OnFloorSubtype(void *data)
 {
-	theApp->floorSubtype = (s32)data;
+	theApp->floorSubtype = (long)data;
 	theApp->imgMouse = &(theApp->level.Theme().Floor(theApp->floorSubtype));
 }
 
 void HCed::OnContFloorSubtype(void *data)
 {
-	theApp->contFloorSubtype = (s32)data;
+	theApp->contFloorSubtype = (long)data;
 	theApp->imgMouse = &(theApp->level.Theme().ContFloor(theApp->contFloorSubtype)[HCFDT_I]);
 }
 
 void HCed::OnBarSubtype(void *data)
 {
-	theApp->barSubtype = (s32)data;
+	theApp->barSubtype = (long)data;
 	theApp->imgMouse = &(theApp->level.Theme().Bar(theApp->barSubtype));
 }
 
 void HCed::OnLadderSubtype(void *data)
 {
-	theApp->ladderSubtype = (s32)data;
+	theApp->ladderSubtype = (long)data;
 	theApp->imgMouse = &(theApp->level.Theme().Ladder(theApp->ladderSubtype));
 }
 
 void HCed::OnBreakSubtype(void *data)
 {
-	theApp->breakSubtype = (s32)data;
+	theApp->breakSubtype = (long)data;
 	theApp->imgMouse = (JImage *)(theApp->level.Theme().Break(theApp->breakSubtype)[HCBDT_NORMAL].Frame(0));
 }
 
 void HCed::OnObjectSubtype(void *data)
 {
-	theApp->objectSubtype = (s32)data;
+	theApp->objectSubtype = (long)data;
 	theApp->imgMouse = (JImage *)(theApp->level.Theme().Object(theApp->objectSubtype)[HCODT_NORMAL].Frame(0));
 }
 
 void HCed::OnRopeSubtype(void *data)
 {
-	theApp->ropeSubtype = (s32)data;
+	theApp->ropeSubtype = (long)data;
 	theApp->imgMouse = &(theApp->level.Theme().Rope(theApp->ropeSubtype)[HCRDT_TOP]);
 }
 
 void HCed::OnRopePeriod(void *data)
 {
-	theApp->ropePeriod = 0.5f + (0.25f * float((s32)data));
+	theApp->ropePeriod = 0.5f + (0.25f * float((long)data));
 }
 
 void HCed::OnEnemySubtype(void *data)
 {
-	theApp->enemySubtype = (s32)data;
+	theApp->enemySubtype = (long)data;
 	theApp->imgMouse = (JImage *)(theApp->GetEnemySprites(theApp->enemyType, theApp->enemySubtype)[HCCDT_STOP].Frame(0));
 }
 
@@ -2928,18 +2932,18 @@ void HCed::OnEnemyType(void *data)
 	// 0 always is a valid subtype so init to that
 	theApp->enemySubtype = 0;
 
-	theApp->enemyType = (HCEnemyType)(s32)data;
+	theApp->enemyType = (HCEnemyType)(long)data;
 	theApp->imgMouse = (JImage *)(theApp->GetEnemySprites(theApp->enemyType, theApp->enemySubtype)[HCCDT_STOP].Frame(0));
 }
 
 void HCed::OnEnemyParam1(void *data)
 {
-	theApp->enemyParam1 = (s32)data;
+	theApp->enemyParam1 = (long)data;
 }
 
 void HCed::OnEnemyParam2(void *data)
 {
-	theApp->enemyParam2 = (s32)data;
+	theApp->enemyParam2 = (long)data;
 }
 
 bool HCed::MouseOverMap()
