@@ -256,9 +256,9 @@ bool HCApp::InitFonts()
 	}
 
 	if (JFont::Init() &&
-			fontSmall.Open(HC_DATA_DIR "font/font.ttf", (s32)JMax(11, height/35)) &&
-			fontMedium.Open(HC_DATA_DIR "font/font.ttf", (s32)JMax(12, height/30)) &&
-			fontLarge.Open(HC_DATA_DIR "font/font.ttf", (s32)JMax(13, height/25)))
+			fontSmall.Open(HC_DATA_DIR "font/font.ttf", (long)JMax(11, height/35)) &&
+			fontMedium.Open(HC_DATA_DIR "font/font.ttf", (long)JMax(12, height/30)) &&
+			fontLarge.Open(HC_DATA_DIR "font/font.ttf", (long)JMax(13, height/25)))
 	{
 		level.SetTimerFont(&fontLarge);
 		return true;
@@ -925,7 +925,7 @@ void HCApp::OnCredits(void *data)
 
 void HCApp::OnDifficulty(void *data)
 {
-	HCPreferences::Prefs()->Difficulty((s32)data);
+	HCPreferences::Prefs()->Difficulty((long)data);
 	HCPreferences::Prefs()->Save();
 	theApp->menu->Menu()->Root();
 }
@@ -933,9 +933,9 @@ void HCApp::OnDifficulty(void *data)
 void HCApp::OnSound(void *data)
 {
 	HCApp *a = (HCApp *)App();
-	a->SoundEnabled(0 != (s32)data);
+	a->SoundEnabled(0 != (long)data);
 
-	if (0 != (s32)data)
+	if (0 != (long)data)
 	{
 		if (a->SoundEnabled())
 		{
@@ -960,7 +960,7 @@ void HCApp::OnSound(void *data)
 
 void HCApp::OnNew(void *data)
 {
-	if (theApp->playlist.GoTo(theApp->playlist[(s32)data]))
+	if (theApp->playlist.GoTo(theApp->playlist[(long)data]))
 	{
 		theApp->levelNumber = 1;
 		theApp->State(HCS_PLAYING);
@@ -981,10 +981,10 @@ void HCApp::OnHelp(void *data)
 void HCApp::OnVideoMode(void *data)
 {
 	HCApp *a = (HCApp *)App();
-	a->preferences.VideoMode((s32)data);
+	a->preferences.VideoMode((long)data);
 	a->preferences.Save();
-	App()->Resize(a->preferences.VideoModes()[(s32)data].w, 
-								a->preferences.VideoModes()[(s32)data].h, 
+	App()->Resize(a->preferences.VideoModes()[(long)data].w, 
+								a->preferences.VideoModes()[(long)data].h, 
 								a->preferences.Fullscreen());
 	a->State(HCS_MENU);
 }
@@ -992,9 +992,9 @@ void HCApp::OnVideoMode(void *data)
 void HCApp::OnBPP(void *data)
 {
 	HCApp *a = (HCApp *)App();
-	a->preferences.BPP((s32)data);
+	a->preferences.BPP((long)data);
 	a->preferences.Save();
-	a->depth = (s32)data;
+	a->depth = (long)data;
 	App()->Resize(a->preferences.VideoModes()[a->preferences.VideoMode()].w, 
 								a->preferences.VideoModes()[a->preferences.VideoMode()].h,
 								a->preferences.Fullscreen());
@@ -1004,7 +1004,7 @@ void HCApp::OnBPP(void *data)
 void HCApp::OnWindowMode(void *data)
 {
 	HCApp *a = (HCApp *)App();
-	a->preferences.Fullscreen((s32)data);
+	a->preferences.Fullscreen((long)data);
 	a->preferences.Save();
 	App()->Resize(a->preferences.VideoModes()[a->preferences.VideoMode()].w, 
 								a->preferences.VideoModes()[a->preferences.VideoMode()].h,
@@ -1015,7 +1015,7 @@ void HCApp::OnWindowMode(void *data)
 void HCApp::OnLanguage(void *data)
 {
 	HCApp *a = (HCApp *)App();
-	a->preferences.CurLang((s32)data);
+	a->preferences.CurLang((long)data);
 	a->preferences.Save();
 	a->State(HCS_MENU);
 }
@@ -1025,8 +1025,8 @@ void HCApp::OnDefaults(void *data)
 	HCApp *a = (HCApp *)App();
 	a->preferences.Reset();
 	a->preferences.Save();
-	App()->Resize(a->preferences.VideoModes()[(s32)data].w, 
-								a->preferences.VideoModes()[(s32)data].h, 
+	App()->Resize(a->preferences.VideoModes()[(long)data].w, 
+								a->preferences.VideoModes()[(long)data].h, 
 								a->preferences.Fullscreen());
 	a->State(HCS_MENU);
 }
@@ -1034,9 +1034,9 @@ void HCApp::OnDefaults(void *data)
 void HCApp::OnLoad(void *data)
 {
 	HCApp *app = (HCApp *)App();
-	if (app->playlist.GoTo(app->saveData[(s32)data].Story()))
+	if (app->playlist.GoTo(app->saveData[(long)data].Story()))
 	{
-		app->levelNumber = app->saveData[(s32)data].Level();
+		app->levelNumber = app->saveData[(long)data].Level();
 		app->State(HCS_PLAYING);
 	}
 }
@@ -1044,7 +1044,7 @@ void HCApp::OnLoad(void *data)
 void HCApp::OnSave(void *data)
 {
 	HCApp *app = (HCApp *)App();
-	if (app->saveData[(s32)data].Save((s32)data, app->playlist.StoryName(), app->levelNumber))
+	if (app->saveData[(long)data].Save((long)data, app->playlist.StoryName(), app->levelNumber))
 	{
 		app->State(HCS_MENU);
 	}
